searchNodes=[{"type":"module","title":"Jason","doc":"A blazing fast JSON parser and generator in pure Elixir.","ref":"Jason.html"},{"type":"function","title":"Jason.decode/2","doc":"Parses a JSON value from input iodata. Options :keys - controls how keys in objects are decoded. Possible values are: :strings (default) - decodes keys as binary strings, :atoms - keys are converted to atoms using String.to_atom/1 , :atoms! - keys are converted to atoms using String.to_existing_atom/1 , custom decoder - additionally a function accepting a string and returning a key is accepted. :strings - controls how strings (including keys) are decoded. Possible values are: :reference (default) - when possible tries to create a sub-binary into the original :copy - always copies the strings. This option is especially useful when parts of the decoded data will be stored for a long time (in ets or some process) to avoid keeping the reference to the original data. :floats - controls how floats are decoded. Possible values are: :native (default) - Native conversion from binary to float using :erlang.binary_to_float/1 , :decimals - uses Decimal.new/1 to parse the binary into a Decimal struct with arbitrary precision. :objects - controls how objects are decoded. Possible values are: :maps (default) - objects are decoded as maps :ordered_objects - objects are decoded as Jason.OrderedObject structs Decoding keys to atoms The :atoms option uses the String.to_atom/1 call that can create atoms at runtime. Since the atoms are not garbage collected, this can pose a DoS attack vector when used on user-controlled data. Examples iex&gt; Jason . decode ( &quot;{}&quot; ) { :ok , %{ } } iex&gt; Jason . decode ( &quot;invalid&quot; ) { :error , % Jason.DecodeError { data : &quot;invalid&quot; , position : 0 , token : nil } }","ref":"Jason.html#decode/2"},{"type":"function","title":"Jason.decode!/2","doc":"Parses a JSON value from input iodata. Similar to decode/2 except it will unwrap the error tuple and raise in case of errors. Examples iex&gt; Jason . decode! ( &quot;{}&quot; ) %{ } iex&gt; Jason . decode! ( &quot;invalid&quot; ) ** (Jason.DecodeError) unexpected byte at position 0: 0x69 (&quot;i&quot;)","ref":"Jason.html#decode!/2"},{"type":"function","title":"Jason.encode/2","doc":"Generates JSON corresponding to input . The generation is controlled by the Jason.Encoder protocol, please refer to the module to read more on how to define the protocol for custom data types. Options :escape - controls how strings are encoded. Possible values are: :json (default) - the regular JSON escaping as defined by RFC 7159. :javascript_safe - additionally escapes the LINE SEPARATOR (U+2028) and PARAGRAPH SEPARATOR (U+2029) characters to make the produced JSON valid JavaScript. :html_safe - similar to :javascript_safe , but also escapes the / character to prevent XSS. :unicode_safe - escapes all non-ascii characters. :maps - controls how maps are encoded. Possible values are: :strict - checks the encoded map for duplicate keys and raises if they appear. For example %{:foo =&gt; 1, &quot;foo&quot; =&gt; 2} would be rejected, since both keys would be encoded to the string &quot;foo&quot; . :naive (default) - does not perform the check. :pretty - controls pretty printing of the output. Possible values are: true to pretty print with default configuration a keyword of options as specified by Jason.Formatter.pretty_print/2 . Examples iex&gt; Jason . encode ( %{ a : 1 } ) { :ok , ~S|{&quot;a&quot;:1}| } iex&gt; Jason . encode ( &quot; \\x FF&quot; ) { :error , % Jason.EncodeError { message : &quot;invalid byte 0xFF in &lt;&lt;255&gt;&gt;&quot; } }","ref":"Jason.html#encode/2"},{"type":"function","title":"Jason.encode!/2","doc":"Generates JSON corresponding to input . Similar to encode/1 except it will unwrap the error tuple and raise in case of errors. Examples iex&gt; Jason . encode! ( %{ a : 1 } ) ~S|{&quot;a&quot;:1}| iex&gt; Jason . encode! ( &quot; \\x FF&quot; ) ** (Jason.EncodeError) invalid byte 0xFF in &lt;&lt;255&gt;&gt;","ref":"Jason.html#encode!/2"},{"type":"function","title":"Jason.encode_to_iodata/2","doc":"Generates JSON corresponding to input and returns iodata. This function should be preferred to encode/2 , if the generated JSON will be handed over to one of the IO functions or sent over the socket. The Erlang runtime is able to leverage vectorised writes and avoid allocating a continuous buffer for the whole resulting string, lowering memory use and increasing performance. Examples iex&gt; { :ok , iodata } = Jason . encode_to_iodata ( %{ a : 1 } ) iex&gt; IO . iodata_to_binary ( iodata ) ~S|{&quot;a&quot;:1}| iex&gt; Jason . encode_to_iodata ( &quot; \\x FF&quot; ) { :error , % Jason.EncodeError { message : &quot;invalid byte 0xFF in &lt;&lt;255&gt;&gt;&quot; } }","ref":"Jason.html#encode_to_iodata/2"},{"type":"function","title":"Jason.encode_to_iodata!/2","doc":"Generates JSON corresponding to input and returns iodata. Similar to encode_to_iodata/1 except it will unwrap the error tuple and raise in case of errors. Examples iex&gt; iodata = Jason . encode_to_iodata! ( %{ a : 1 } ) iex&gt; IO . iodata_to_binary ( iodata ) ~S|{&quot;a&quot;:1}| iex&gt; Jason . encode_to_iodata! ( &quot; \\x FF&quot; ) ** (Jason.EncodeError) invalid byte 0xFF in &lt;&lt;255&gt;&gt;","ref":"Jason.html#encode_to_iodata!/2"},{"type":"type","title":"Jason.decode_opt/0","doc":"","ref":"Jason.html#t:decode_opt/0"},{"type":"type","title":"Jason.encode_opt/0","doc":"","ref":"Jason.html#t:encode_opt/0"},{"type":"type","title":"Jason.escape/0","doc":"","ref":"Jason.html#t:escape/0"},{"type":"type","title":"Jason.floats/0","doc":"","ref":"Jason.html#t:floats/0"},{"type":"type","title":"Jason.keys/0","doc":"","ref":"Jason.html#t:keys/0"},{"type":"type","title":"Jason.maps/0","doc":"","ref":"Jason.html#t:maps/0"},{"type":"type","title":"Jason.objects/0","doc":"","ref":"Jason.html#t:objects/0"},{"type":"type","title":"Jason.strings/0","doc":"","ref":"Jason.html#t:strings/0"},{"type":"module","title":"Jason.Encode","doc":"Utilities for encoding elixir values to JSON.","ref":"Jason.Encode.html"},{"type":"function","title":"Jason.Encode.atom/2","doc":"","ref":"Jason.Encode.html#atom/2"},{"type":"function","title":"Jason.Encode.float/1","doc":"","ref":"Jason.Encode.html#float/1"},{"type":"function","title":"Jason.Encode.integer/1","doc":"","ref":"Jason.Encode.html#integer/1"},{"type":"function","title":"Jason.Encode.keyword/2","doc":"","ref":"Jason.Encode.html#keyword/2"},{"type":"function","title":"Jason.Encode.list/2","doc":"","ref":"Jason.Encode.html#list/2"},{"type":"function","title":"Jason.Encode.map/2","doc":"","ref":"Jason.Encode.html#map/2"},{"type":"function","title":"Jason.Encode.string/2","doc":"","ref":"Jason.Encode.html#string/2"},{"type":"function","title":"Jason.Encode.struct/2","doc":"","ref":"Jason.Encode.html#struct/2"},{"type":"function","title":"Jason.Encode.value/2","doc":"Equivalent to calling the Jason.Encoder.encode/2 protocol function. Slightly more efficient for built-in types because of the internal dispatching.","ref":"Jason.Encode.html#value/2"},{"type":"opaque","title":"Jason.Encode.opts/0","doc":"","ref":"Jason.Encode.html#t:opts/0"},{"type":"protocol","title":"Jason.Encoder","doc":"Protocol controlling how a value is encoded to JSON. Deriving The protocol allows leveraging the Elixir's @derive feature to simplify protocol implementation in trivial cases. Accepted options are: :only - encodes only values of specified keys. :except - encodes all struct fields except specified keys. By default all keys except the :__struct__ key are encoded. Example Let's assume a presence of the following struct: defmodule Test do defstruct [ :foo , :bar , :baz ] end If we were to call @derive Jason.Encoder just before defstruct , an implementation similar to the following implementation would be generated: defimpl Jason.Encoder , for : Test do def encode ( value , opts ) do Jason.Encode . map ( Map . take ( value , [ :foo , :bar , :baz ] ) , opts ) end end If we called @derive {Jason.Encoder, only: [:foo]} , an implementation similar to the following implementation would be generated: defimpl Jason.Encoder , for : Test do def encode ( value , opts ) do Jason.Encode . map ( Map . take ( value , [ :foo ] ) , opts ) end end If we called @derive {Jason.Encoder, except: [:foo]} , an implementation similar to the following implementation would be generated: defimpl Jason.Encoder , for : Test do def encode ( value , opts ) do Jason.Encode . map ( Map . take ( value , [ :bar , :baz ] ) , opts ) end end The actually generated implementations are more efficient computing some data during compilation similar to the macros from the Jason.Helpers module. Explicit implementation If you wish to implement the protocol fully yourself, it is advised to use functions from the Jason.Encode module to do the actual iodata generation - they are highly optimized and verified to always produce valid JSON.","ref":"Jason.Encoder.html"},{"type":"function","title":"Jason.Encoder.encode/2","doc":"Encodes value to JSON. The argument opts is opaque - it can be passed to various functions in Jason.Encode (or to the protocol function itself) for encoding values to JSON.","ref":"Jason.Encoder.html#encode/2"},{"type":"type","title":"Jason.Encoder.opts/0","doc":"","ref":"Jason.Encoder.html#t:opts/0"},{"type":"type","title":"Jason.Encoder.t/0","doc":"","ref":"Jason.Encoder.html#t:t/0"},{"type":"module","title":"Jason.Formatter","doc":"Pretty-printing and minimizing functions for JSON-encoded data. Input is required to be in an 8-bit-wide encoding such as UTF-8 or Latin-1 in iodata/0 format. Input must have valid JSON, invalid JSON may produce unexpected results or errors.","ref":"Jason.Formatter.html"},{"type":"function","title":"Jason.Formatter.minimize/2","doc":"Minimizes JSON-encoded input . input may contain multiple JSON objects or arrays, optionally separated by whitespace (e.g., one object per line). Minimized output will contain one object per line. No trailing newline is emitted. Options :record_separator - controls the string used as newline (default: &quot;\\n&quot; ). Examples iex&gt; Jason.Formatter . minimize ( ~s|{ &quot;a&quot; : &quot;b&quot; , &quot;c&quot;: \\n \\n 2}| ) ~s|{&quot;a&quot;:&quot;b&quot;,&quot;c&quot;:2}|","ref":"Jason.Formatter.html#minimize/2"},{"type":"function","title":"Jason.Formatter.minimize_to_iodata/2","doc":"Minimizes JSON-encoded input and returns iodata. This function should be preferred to minimize/2 , if the minimized JSON will be handed over to one of the IO functions or sent over the socket. The Erlang runtime is able to leverage vectorised writes and avoid allocating a continuous buffer for the whole resulting string, lowering memory use and increasing performance.","ref":"Jason.Formatter.html#minimize_to_iodata/2"},{"type":"function","title":"Jason.Formatter.pretty_print/2","doc":"Pretty-prints JSON-encoded input . input may contain multiple JSON objects or arrays, optionally separated by whitespace (e.g., one object per line). Objects in output will be separated by newlines. No trailing newline is emitted. Options :indent - used for nested objects and arrays (default: two spaces - &quot; &quot; ); :line_separator - used in nested objects (default: &quot;\\n&quot; ); :record_separator - separates root-level objects and arrays (default is the value for :line_separator option); :after_colon - printed after a colon inside objects (default: one space - &quot; &quot; ). Examples iex&gt; Jason.Formatter . pretty_print ( ~s|{&quot;a&quot;:{&quot;b&quot;: [1, 2]}}| ) ~s|{ &quot;a&quot;: { &quot;b&quot;: [ 1, 2 ] } }|","ref":"Jason.Formatter.html#pretty_print/2"},{"type":"function","title":"Jason.Formatter.pretty_print_to_iodata/2","doc":"Pretty-prints JSON-encoded input and returns iodata. This function should be preferred to pretty_print/2 , if the pretty-printed JSON will be handed over to one of the IO functions or sent over the socket. The Erlang runtime is able to leverage vectorised writes and avoid allocating a continuous buffer for the whole resulting string, lowering memory use and increasing performance.","ref":"Jason.Formatter.html#pretty_print_to_iodata/2"},{"type":"type","title":"Jason.Formatter.opts/0","doc":"","ref":"Jason.Formatter.html#t:opts/0"},{"type":"module","title":"Jason.Fragment","doc":"Provides a way to inject an already-encoded JSON structure into a to-be-encoded structure in optimized fashion. This avoids a decoding/encoding round-trip for the subpart. This feature can be used for caching parts of the JSON, or delegating the generation of the JSON to a third-party system (e.g. Postgres).","ref":"Jason.Fragment.html"},{"type":"function","title":"Jason.Fragment.new/1","doc":"","ref":"Jason.Fragment.html#new/1"},{"type":"module","title":"Jason.Helpers","doc":"Provides macro facilities for partial compile-time encoding of JSON.","ref":"Jason.Helpers.html"},{"type":"macro","title":"Jason.Helpers.json_map/1","doc":"Encodes a JSON map from a compile-time keyword. Encodes the keys at compile time and strives to create as flat iodata structure as possible to achieve maximum efficiency. Does encoding right at the call site, but returns an %Jason.Fragment{} struct that needs to be passed to one of the &quot;main&quot; encoding functions - for example Jason.encode/2 for final encoding into JSON - this makes it completely transparent for most uses. Only allows keys that do not require escaping in any of the supported encoding modes. This means only ASCII characters from the range 0x1F..0x7F excluding '\\', '/' and '&quot;' are allowed - this also excludes all control characters like newlines. Preserves the order of the keys. Example iex&gt; fragment = json_map ( foo : 1 , bar : 2 ) iex&gt; Jason . encode! ( fragment ) &quot;{ \\&quot; foo \\&quot; :1, \\&quot; bar \\&quot; :2}&quot;","ref":"Jason.Helpers.html#json_map/1"},{"type":"macro","title":"Jason.Helpers.json_map_take/2","doc":"Encodes a JSON map from a variable containing a map and a compile-time list of keys. It is equivalent to calling Map.take/2 before encoding. Otherwise works similar to json_map/2 . Example iex&gt; map = %{ a : 1 , b : 2 , c : 3 } iex&gt; fragment = json_map_take ( map , [ :c , :b ] ) iex&gt; Jason . encode! ( fragment ) &quot;{ \\&quot; c \\&quot; :3, \\&quot; b \\&quot; :2}&quot;","ref":"Jason.Helpers.html#json_map_take/2"},{"type":"module","title":"Jason.OrderedObject","doc":"","ref":"Jason.OrderedObject.html"},{"type":"function","title":"Jason.OrderedObject.__struct__/0","doc":"Struct implementing a JSON object retaining order of properties. A wrapper around a keyword (that supports non-atom keys) allowing for proper protocol implementations. Implements the Access behaviour and Enumerable protocol with complexity similar to keywords/lists.","ref":"Jason.OrderedObject.html#__struct__/0"},{"type":"function","title":"Jason.OrderedObject.new/1","doc":"","ref":"Jason.OrderedObject.html#new/1"},{"type":"type","title":"Jason.OrderedObject.t/0","doc":"","ref":"Jason.OrderedObject.html#t:t/0"},{"type":"module","title":"Jason.Sigil","doc":"","ref":"Jason.Sigil.html"},{"type":"macro","title":"Jason.Sigil.sigil_J/2","doc":"Handles the sigil ~J for raw JSON strings. Decodes a raw string ignoring Elixir interpolations and escape characters at compile-time. Examples iex&gt; ~J&#39;&quot;\#{string}&quot;&#39; &quot; \\# {string}&quot; iex&gt; ~J&#39;&quot;\\u0078\\\\y&quot;&#39; &quot;x \\\\ y&quot; iex&gt; ~J&#39;{&quot;\#{key}&quot;: &quot;\#{}&quot;}&#39;a %{ &quot; \\# {key}&quot; : &quot; \\# {}&quot; }","ref":"Jason.Sigil.html#sigil_J/2"},{"type":"macro","title":"Jason.Sigil.sigil_j/2","doc":"Handles the sigil ~j for JSON strings. Calls Jason.decode!/2 with modifiers mapped to options. Given a string literal without interpolations, decodes the string at compile-time. Modifiers See Jason.decode/2 for detailed descriptions. a - equivalent to {:keys, :atoms} option A - equivalent to {:keys, :atoms!} option r - equivalent to {:strings, :reference} option c - equivalent to {:strings, :copy} option Examples iex&gt; ~j&quot;0&quot; 0 iex&gt; ~j&quot;[1, 2, 3]&quot; [ 1 , 2 , 3 ] iex&gt; ~j&#39;&quot;string&quot;&#39;r &quot;string&quot; iex&gt; ~j&quot;{}&quot; %{ } iex&gt; ~j&#39;{&quot;atom&quot;: &quot;value&quot;}&#39;a %{ atom : &quot;value&quot; } iex&gt; ~j&#39;{&quot; \#{ :j } &quot;: \#{ &#39;&quot;j&quot;&#39; } }&#39;A %{ j : &quot;j&quot; }","ref":"Jason.Sigil.html#sigil_j/2"},{"type":"exception","title":"Jason.DecodeError","doc":"","ref":"Jason.DecodeError.html"},{"type":"function","title":"Jason.DecodeError.message/1","doc":"Callback implementation for Exception.message/1 .","ref":"Jason.DecodeError.html#message/1"},{"type":"type","title":"Jason.DecodeError.t/0","doc":"","ref":"Jason.DecodeError.html#t:t/0"},{"type":"exception","title":"Jason.EncodeError","doc":"","ref":"Jason.EncodeError.html"},{"type":"function","title":"Jason.EncodeError.new/1","doc":"","ref":"Jason.EncodeError.html#new/1"},{"type":"type","title":"Jason.EncodeError.t/0","doc":"","ref":"Jason.EncodeError.html#t:t/0"},{"type":"extras","title":"Jason","doc":"A blazing fast JSON parser and generator in pure Elixir. The parser and generator are at least twice as fast as other Elixir/Erlang libraries (most notably Poison ). The performance is comparable to jiffy , which is implemented in C as a NIF. Jason is usually only twice as slow. Both parser and generator fully conform to RFC 8259 and ECMA 404 standards. The parser is tested using JSONTestSuite .","ref":"readme.html"},{"type":"extras","title":"Jason - Installation","doc":"The package can be installed by adding jason to your list of dependencies in mix.exs : def deps do [ { :jason , &quot;~&gt; 1.4&quot; } ] end","ref":"readme.html#installation"},{"type":"extras","title":"Jason - Basic Usage","doc":"iex(1)&gt; Jason . encode! ( %{ &quot;age&quot; =&gt; 44 , &quot;name&quot; =&gt; &quot;Steve Irwin&quot; , &quot;nationality&quot; =&gt; &quot;Australian&quot; } ) &quot;{ \\&quot; age \\&quot; :44, \\&quot; name \\&quot; : \\&quot; Steve Irwin \\&quot; , \\&quot; nationality \\&quot; : \\&quot; Australian \\&quot; }&quot; iex(2)&gt; Jason . decode! ( ~s({&quot;age&quot;:44,&quot;name&quot;:&quot;Steve Irwin&quot;,&quot;nationality&quot;:&quot;Australian&quot;}) ) %{ &quot;age&quot; =&gt; 44 , &quot;name&quot; =&gt; &quot;Steve Irwin&quot; , &quot;nationality&quot; =&gt; &quot;Australian&quot; } Full documentation can be found at https://hexdocs.pm/jason .","ref":"readme.html#basic-usage"},{"type":"extras","title":"Jason - Use with other libraries","doc":"Postgrex Versions starting at 0.14.0 use Jason by default. For earlier versions, please refer to previous versions of this document . Ecto Versions starting at 3.0.0 use Jason by default. For earlier versions, please refer to previous versions of this document . Plug (and Phoenix) Phoenix starting at 1.4.0 uses Jason by default. For earlier versions, please refer to previous versions of this document . Absinthe You need to pass the :json_codec option to Absinthe.Plug # When called directly: plug Absinthe.Plug , schema : MyApp.Schema , json_codec : Jason # When used in phoenix router: forward &quot;/api&quot; , to : Absinthe.Plug , init_opts : [ schema : MyApp.Schema , json_codec : Jason ]","ref":"readme.html#use-with-other-libraries"},{"type":"extras","title":"Jason - Benchmarks","doc":"Detailed benchmarks (including memory measurements): https://gist.github.com/michalmuskala/4d64a5a7696ca84ac7c169a0206640d5 HTML reports for the benchmark (only performance measurements): http://michal.muskala.eu/jason/decode.html and http://michal.muskala.eu/jason/encode.html Running Benchmarks against most popular Elixir &amp; Erlang json libraries can be executed after going into the bench/ folder and then executing mix bench.encode and mix bench.decode . A HTML report of the benchmarks (after their execution) can be found in bench/output/encode.html and bench/output/decode.html respectively.","ref":"readme.html#benchmarks"},{"type":"extras","title":"Jason - Differences to Poison","doc":"Jason has a couple feature differences compared to Poison. Jason follows the JSON spec more strictly, for example it does not allow unescaped newline characters in JSON strings - e.g. &quot;\\&quot;\\n\\&quot;&quot; will produce a decoding error. no support for decoding into data structures (the as: option). no built-in encoders for MapSet , Range and Stream . no support for encoding arbitrary structs - explicit implementation of the Jason.Encoder protocol is always required. different pretty-printing customisation options (default pretty: true works the same) Encoders If you require encoders for any of the unsupported collection types, I suggest adding the needed implementations directly to your project: defimpl Jason.Encoder , for : [ MapSet , Range , Stream ] do def encode ( struct , opts ) do Jason.Encode . list ( Enum . to_list ( struct ) , opts ) end end If you need to encode some struct that does not implement the protocol, if you own the struct, you can derive the implementation specifying which fields should be encoded to JSON: @derive { Jason.Encoder , only : [ ... . ] } defstruct # ... It is also possible to encode all fields, although this should be used carefully to avoid accidentally leaking private information when new fields are added: @derive Jason.Encoder defstruct # ... Finally, if you don't own the struct you want to encode to JSON, you may use Protocol.derive/3 placed outside of any module: Protocol . derive ( Jason.Encoder , NameOfTheStruct , only : [ ... ] ) Protocol . derive ( Jason.Encoder , NameOfTheStruct )","ref":"readme.html#differences-to-poison"},{"type":"extras","title":"Jason - Injecting an already encoded JSON inside a to-be-encoded structure","doc":"If parts of the to-be-encoded structure are already JSON-encoded, you can use Jason.Fragment to mark the parts as already encoded, and avoid a decoding/encoding roundtrip. already_encoded_json = Jason . encode! ( %{ hello : &quot;world&quot; } ) Jason . encode! ( %{ foo : Jason.Fragment . new ( already_encoded_json ) } ) ` ` ` ` This feature is especially useful if you need to cache a part of the JSON , or if it is already provided by another system ( e . g . ` jsonb_agg ` with Postgres ) . ## License Jason is released under the Apache License 2.0 - see the [ LICENSE ] ( LICENSE ) file . Some elements of tests and benchmarks have their origins in the [ Poison library ] ( https :// github . com / devinus / poison ) and were initially licensed under [ CC0 - 1.0 ] ( https :// creativecommons . org / publicdomain / zero / 1.0 / ) .","ref":"readme.html#injecting-an-already-encoded-json-inside-a-to-be-encoded-structure"},{"type":"extras","title":"Changelog","doc":"","ref":"changelog.html"},{"type":"extras","title":"Changelog - 1.5.0-alpha.2 (07.07.2023)","doc":"Add limit to decoded integer sizes of 1024 digits. This can be changed with the decoding_integer_digit_limit app env config.","ref":"changelog.html#1-5-0-alpha-2-07-07-2023"},{"type":"extras","title":"Changelog - 1.4.1 (06.07.2023)","doc":"Add limit to decoded integer sizes of 1024 digits. This can be changed with the decoding_integer_digit_limit app env config.","ref":"changelog.html#1-4-1-06-07-2023"},{"type":"extras","title":"Changelog - 1.5.0-alpha.1 (16.10.2022)","doc":"Enhancements Add optional dependency for jason_native . Please refer to the repo for usage instructions","ref":"changelog.html#1-5-0-alpha-1-16-10-2022"},{"type":"extras","title":"Changelog - 1.4.0 (12.09.2022)","doc":"Enhancements Use the :erlang.float_to_binary(_, [:short]) function, instead of io_lib_format.fwrite_g/1 where available (OTP 24.1+). This provides equivalent output with much less memory used and significantly improved performance.","ref":"changelog.html#1-4-0-12-09-2022"},{"type":"extras","title":"Changelog - 1.3.0 (21.12.2021)","doc":"Enhancements Add the Jason.OrderedObject struct Support decoding objects preserving all the keys with objects: :ordered_objects option Support decoding floats to Decimal with floats: :decimals option Add ~j and ~J sigils in module Jason.Sigil to support writing JSON literals in code Fixes Fix error reporting when decoding strings (it was possible to mis-attribute the offending byte) Verify fields given to @derive","ref":"changelog.html#1-3-0-21-12-2021"},{"type":"extras","title":"Changelog - 1.2.2 (08.09.2020)","doc":"Enhancements Support Decimal 2.0","ref":"changelog.html#1-2-2-08-09-2020"},{"type":"extras","title":"Changelog - 1.2.1 (04.05.2020)","doc":"Security Fix html_safe escaping in Jason.encode The &lt;!-- sequence of characters would not be escaped in Jason.encode with html_escape  mode, which could lead to DoS attacks when used for embedding of arbitrary, user controlled strings into HTML through JSON (e.g. inside of &lt;script&gt; tags). If you were not using the html_safe option, you are not affected. Affected versions: &lt; 1.2.1 Patched versions: &gt;= 1.2.1","ref":"changelog.html#1-2-1-04-05-2020"},{"type":"extras","title":"Changelog - 1.2.0 (17.03.2020)","doc":"Enhancements Add Jason.Encode.keyword/2 ( cb1f26a ). Bug fixes Fix Jason.Helpers.json_map/1 value expansion ( 70b046a ).","ref":"changelog.html#1-2-0-17-03-2020"},{"type":"extras","title":"Changelog - 1.1.2 (19.10.2018)","doc":"Bug fixes correctly handle the pretty: false option ( ba318c8 ).","ref":"changelog.html#1-1-2-19-10-2018"},{"type":"extras","title":"Changelog - 1.1.1 (10.07.2018)","doc":"Bug fixes correctly handle escape sequences in strings when pretty printing ( 794bbe4 ).","ref":"changelog.html#1-1-1-10-07-2018"},{"type":"extras","title":"Changelog - 1.1.0 (02.07.2018)","doc":"Enhancements pretty-printing support through Jason.Formatter and pretty: true option in Jason.encode/2 ( d758e36 ). Bug fixes silence variable warnings for fields with underscores used during deriving ( 88dd85c ). potential incompatibility don't raise Protocol.UndefinedError in non-bang functions ( ad0f57b ).","ref":"changelog.html#1-1-0-02-07-2018"},{"type":"extras","title":"Changelog - 1.0.1 (02.07.2018)","doc":"Bug fixes fix Jason.Encode.escape type ( a57b430 ) multiple documentation improvements","ref":"changelog.html#1-0-1-02-07-2018"},{"type":"extras","title":"Changelog - 1.0.0 (26.01.2018)","doc":"No changes","ref":"changelog.html#1-0-0-26-01-2018"},{"type":"extras","title":"Changelog - 1.0.0-rc.3 (26.01.2018)","doc":"Changes update escape option of Jason.encode/2 to take values: :json | :unicode_safe | :html_safe | :javascript_safe for consistency. Old values of :unicode and :javascript are still supported for compatibility with Poison. ( f42dcbd )","ref":"changelog.html#1-0-0-rc-3-26-01-2018"},{"type":"extras","title":"Changelog - 1.0.0-rc.2 (07.01.2018)","doc":"Bug fixes add type for strings option ( b459ee4 ) support iodata in decode! ( a1f3456 )","ref":"changelog.html#1-0-0-rc-2-07-01-2018"},{"type":"extras","title":"Changelog - 1.0.0-rc.1 (22.12.2017)","doc":"Initial release","ref":"changelog.html#1-0-0-rc-1-22-12-2017"},{"type":"extras","title":"LICENSE","doc":"Copyright (c) 2017-present Michał Muskała Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html"}]